@@ -24,9 +24,6 @@ class Yolo(Base):
         self.classes = None
         self.options = options
         self.is_locked = False
-
-        #g.logger.Debug (4, 'Yolo init params: {}'.format(options))
-
         self.processor=self.options.get('object_processor') or 'cpu'
         self.lock_maximum=int(options.get(self.processor+'_max_processes') or 1)
         self.lock_timeout = int(options.get(self.processor+'_max_lock_wait') or 120)
@@ -36,7 +33,7 @@ class Yolo(Base):
 
         self.disable_locks = options.get('disable_locks', 'no')
         if self.disable_locks == 'no':
-            g.logger.Debug (2,f'portalock: max:{self.lock_maximum}, name:{self.lock_name}, timeout:{self.lock_timeout}')
+            g.logger.Debug (2,'portalock: max:{}, name:{}, timeout:{}'.format(self.lock_maximum, self.lock_name, self.lock_timeout))
             self.lock = portalocker.BoundedSemaphore(maximum=self.lock_maximum, name=self.lock_name,timeout=self.lock_timeout)
         self.model_height = self.options.get('model_height', 416)
         self.model_width = self.options.get('model_width', 416)
@@ -48,9 +45,9 @@ class Yolo(Base):
             g.logger.Debug(2, '{} portalock already acquired'.format(self.lock_name))
             return
         try:
-            g.logger.Debug (2,f'Waiting for {self.lock_name} portalock...')
+            g.logger.Debug (2,'Waiting for {} portalock...'.format(self.lock_name))
             self.lock.acquire()
-            g.logger.Debug (2,f'Got {self.lock_name} portalock')
+            g.logger.Debug (2,'Got {} portalock'.format(self.lock_name))
             self.is_locked = True
            
         except portalocker.AlreadyLocked:
